Radon is a radioactive gas that enters homes through contact points with the
ground. It is a carcinogen that is the primary cause of lung cancer in
non-smokers. Radon levels vary greatly from household to household. This dataset
contains measured radon levels in U.S homes by county and state. The 'activity'
label is the measured radon concentration in pCi/L. Important predictors are
'floor' (the floor of the house in which the measurement was taken), 'county'
(the U.S. county in which the house is located), and 'Uppm' (a measurement of
uranium level of the soil by county).
